Date: 2022-10-01T06:40:31+00:00

Actual source code: slepcpepmod.F90
slepc-3.18.0 2022-10-01
Report Typos and Errors

      1: !
      2: !  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      3: !  SLEPc - Scalable Library for Eigenvalue Problem Computations
      4: !  Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
      5: !
      6: !  This file is part of SLEPc.
      7: !  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
      8: !  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      9: !
     10:         module slepcpepdef
     11:         use slepcsys
     12:         use slepcstdef
     13:         use slepcbvdef
     14:         use slepcrgdef
     15:         use slepcdsdef
     16:         use slepcepsdef
     17: #include <../src/pep/f90-mod/slepcpep.h>
     18:         end module

     20:         module slepcpep
     21:         use slepcpepdef
     22:         use slepceps
     23: #include <../src/pep/f90-mod/slepcpep.h90>
     24:         interface
     25: #include <../src/pep/f90-mod/ftn-auto-interfaces/slepcpep.h90>
     26:         end interface
     27:         end module